==> hubzero-submit-common_2.0.8.orig.tar.gz: hubzero-submit-common-2.0.8/hubzero/submit/LogMessage.py <==
# @package      hubzero-submit-common
# @file         LogMessage.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import sys
import os
import time

LOGMESSAGEFILE = sys.stdout
LOGJOBID       = 0

def getLogMessageFileNo():
   global LOGMESSAGEFILE

   logMessageFileNo = None
   if LOGMESSAGEFILE:
      logMessageFileNo = LOGMESSAGEFILE.fileno()

   return(logMessageFileNo)


def openLog(logName):
   global LOGMESSAGEFILE

   try:
      LOGMESSAGEFILE = open(logName,'a')
   except:
      LOGMESSAGEFILE = sys.stdout


def logSetMessageFile(fpMessageFile):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE:
      if LOGMESSAGEFILE.fileno() != sys.stdout.fileno() and \
         LOGMESSAGEFILE.fileno() != sys.stderr.fileno():
         LOGMESSAGEFILE.close()
   LOGMESSAGEFILE = None

   if fpMessageFile:
      LOGMESSAGEFILE = fpMessageFile


def log(message):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] %s\n" % (time.ctime(),message))
      LOGMESSAGEFILE.flush()


def logPID(message):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] (%d) %s\n" % (time.ctime(),os.getpid(),message))
      LOGMESSAGEFILE.flush()


def logSetJobId(jobId):
   global LOGJOBID

   LOGJOBID = jobId


def logJobId(message):
   global LOGMESSAGEFILE
   global LOGJOBID

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] %d: %s\n" % (time.ctime(),LOGJOBID,message))
      LOGMESSAGEFILE.flush()


def logID(message):
   global LOGJOBID

   if message != "":
      if LOGJOBID > 0:
         logJobId(message)
      else:
         logPID(message)

==> hubzero-submit-common_2.5.6.orig.tar.gz: hubzero-submit-common-2.5.6/hubzero/submit/LogMessage.py <==
# @package      hubzero-submit-common
# @file         LogMessage.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import sys
import os
import time

LOGMESSAGEFILE = sys.stdout
LOGJOBID       = 0

def getLogMessageFileNo():
   global LOGMESSAGEFILE

   logMessageFileNo = None
   if LOGMESSAGEFILE:
      logMessageFileNo = LOGMESSAGEFILE.fileno()

   return(logMessageFileNo)


def openLog(logName):
   global LOGMESSAGEFILE

   try:
      LOGMESSAGEFILE = open(logName,'a')
   except:
      LOGMESSAGEFILE = sys.stdout


def logSetMessageFile(fpMessageFile):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE:
      if LOGMESSAGEFILE.fileno() != sys.stdout.fileno() and \
         LOGMESSAGEFILE.fileno() != sys.stderr.fileno():
         LOGMESSAGEFILE.close()
   LOGMESSAGEFILE = None

   if fpMessageFile:
      LOGMESSAGEFILE = fpMessageFile


def log(message):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] %s\n" % (time.ctime(),message))
      LOGMESSAGEFILE.flush()


def logPID(message):
   global LOGMESSAGEFILE

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] (%d) %s\n" % (time.ctime(),os.getpid(),message))
      LOGMESSAGEFILE.flush()


def logSetJobId(jobId):
   global LOGJOBID

   LOGJOBID = jobId


def logJobId(message):
   global LOGMESSAGEFILE
   global LOGJOBID

   if LOGMESSAGEFILE and message != "":
      LOGMESSAGEFILE.write("[%s] %d: %s\n" % (time.ctime(),LOGJOBID,message))
      LOGMESSAGEFILE.flush()


def logID(message):
   global LOGJOBID

   if message != "":
      if LOGJOBID > 0:
         logJobId(message)
      else:
         logPID(message)


def isLogMessageFileStdout():
   global LOGMESSAGEFILE

   logMessageFileIsStdout = False
   if LOGMESSAGEFILE:
      if LOGMESSAGEFILE.fileno() == sys.stdout.fileno():
         logMessageFileIsStdout = True

   return(logMessageFileIsStdout)


def isLogMessageFileStderr():
   global LOGMESSAGEFILE

   logMessageFileIsStderr = False
   if LOGMESSAGEFILE:
      if LOGMESSAGEFILE.fileno() == sys.stderr.fileno():
         logMessageFileIsStderr = True

   return(logMessageFileIsStderr)


def isLoggingOn():
   global LOGMESSAGEFILE

   return(LOGMESSAGEFILE != None)
